/* Copyright (c) 2020, The Tor Project, Inc. */
/* See LICENSE for licensing information */

/**
 * \file trace.c
 * \brief Common functions for event-tracing implementation
 *
 * See trace.h and doc/HACKING/Tracing.md for more information.
 **/

#include "lib/trace/trace.h"

/** Initialize the tracing library. */
void
tor_trace_init(void)
{
}

/** Free all the tracing library. */
void
tor_trace_free_all(void)
{
}
